==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let RelativeStrengthIndexIndicator = /*@__PURE__*/ (() => {
    class RelativeStrengthIndexIndicator extends StrategyBasedIndicator {
        get_x5() {
            return 1;
        }
        constructor() {
            super();
        }
        get_yy() {
            return new RelativeStrengthIndexIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return RelativeStrengthIndexIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.zk));
        }
        set zj(a) {
            this.h(RelativeStrengthIndexIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    RelativeStrengthIndexIndicator.$t = /*@__PURE__*/ markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let RelativeStrengthIndexIndicator = /*@__PURE__*/ (() => {
    class RelativeStrengthIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new RelativeStrengthIndexIndicator();
        }
        get_aax() {
            return 1;
        }
        constructor() {
            super();
        }
        get_abq() {
            return new RelativeStrengthIndexIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return RelativeStrengthIndexIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.acc));
        }
        set acb(a) {
            this.h(RelativeStrengthIndexIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    RelativeStrengthIndexIndicator.$t = /*@__PURE__*/ markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
})();
